@@ -20,15 +20,15 @@ __all__ = ["aer2ecef", "ecef2aer", "geodetic2aer", "aer2geodetic", "eci2aer", "a
 
 
 def ecef2aer(
-    x: float | ndarray,
-    y: float | ndarray,
-    z: float | ndarray,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    x: ndarray,
+    y: ndarray,
+    z: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float, float, float]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     compute azimuth, elevation and slant range from an Observer to a Point with ECEF coordinates.
 
@@ -69,15 +69,15 @@ def ecef2aer(
 
 
 def geodetic2aer(
-    lat: float,
-    lon: float,
-    h: float,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    lat: ndarray,
+    lon: ndarray,
+    h: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float, float, float]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     gives azimuth, elevation and slant range from an Observer to a Point with geodetic coordinates.
 
@@ -117,15 +117,15 @@ def geodetic2aer(
 
 
 def aer2geodetic(
-    az: float,
-    el: float,
-    srange: float,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    az: ndarray,
+    el: ndarray,
+    srange: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     gives geodetic coordinates of a point with az, el, range
     from an observer at lat0, lon0, h0
@@ -167,17 +167,17 @@ def aer2geodetic(
 
 
 def eci2aer(
-    x: float,
-    y: float,
-    z: float,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    x: ndarray,
+    y: ndarray,
+    z: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     t: datetime,
     *,
     deg: bool = True,
     use_astropy: bool = True
-) -> tuple[float, float, float]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     takes Earth Centered Inertial x,y,z ECI coordinates of point and gives az, el, slant range from Observer
 
@@ -221,18 +221,18 @@ def eci2aer(
 
 
 def aer2eci(
-    az: float,
-    el: float,
-    srange: float,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    az: ndarray,
+    el: ndarray,
+    srange: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     t: datetime,
     ell=None,
     *,
     deg: bool = True,
     use_astropy: bool = True
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     gives ECI of a point from an observer at az, el, slant range
 
@@ -280,15 +280,15 @@ def aer2eci(
 
 
 def aer2ecef(
-    az: float,
-    el: float,
-    srange: float,
-    lat0: float,
-    lon0: float,
-    alt0: float,
+    az: ndarray,
+    el: ndarray,
+    srange: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    alt0: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float, float, float]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     converts target azimuth, elevation, range from observer at lat0,lon0,alt0 to ECEF coordinates.
 
