@@ -15,12 +15,10 @@ try:
         arctan2 as atan2,
         sqrt,
         pi,
-        vectorize,
     )
 except ImportError:
     from math import radians, sin, cos, tan, atan, hypot, degrees, atan2, sqrt, pi  # type: ignore
 
-    vectorize = None
     ndarray = typing.Any  # type: ignore
 
 from datetime import datetime
@@ -51,12 +49,12 @@ __all__ = [
 
 
 def geodetic2ecef(
-    lat: float | ndarray,
-    lon: float | ndarray,
-    alt: float | ndarray,
+    lat: ndarray,
+    lon: ndarray,
+    alt: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     point transformation from Geodetic of specified ellipsoid (default WGS-84) to ECEF
 
@@ -105,27 +103,12 @@ def geodetic2ecef(
 
 
 def ecef2geodetic(
-    x: float | ndarray,
-    y: float | ndarray,
-    z: float | ndarray,
+    x: ndarray,
+    y: ndarray,
+    z: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
-    if vectorize is not None:
-        fun = vectorize(ecef2geodetic_point)
-        lat, lon, alt = fun(x, y, z, ell, deg)
-        return lat[()], lon[()], alt[()]
-    else:
-        return ecef2geodetic_point(x, y, z, ell, deg)
-
-
-def ecef2geodetic_point(
-    x: float | ndarray,
-    y: float | ndarray,
-    z: float | ndarray,
-    ell: Ellipsoid = None,
-    deg: bool = True,
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     convert ECEF (meters) to geodetic coordinates
 
@@ -155,6 +138,7 @@ def ecef2geodetic_point(
     You, Rey-Jer. (2000). Transformation of Cartesian to Geodetic Coordinates without Iterations.
     Journal of Surveying Engineering. doi: 10.1061/(ASCE)0733-9453
     """
+
     if ell is None:
         ell = Ellipsoid()
 
@@ -199,8 +183,14 @@ def ecef2geodetic_point(
         + z ** 2 / ell.semiminor_axis ** 2
         < 1
     )
-    if inside:
-        alt = -alt
+
+    try:
+        if inside.any():  # type: ignore
+            # avoid all false assignment bug
+            alt[inside] = -alt[inside]
+    except (TypeError, AttributeError):
+        if inside:
+            alt = -alt
 
     if deg:
         lat = degrees(lat)
@@ -255,15 +245,15 @@ def ecef2enuv(
 
 
 def ecef2enu(
-    x: float | ndarray,
-    y: float | ndarray,
-    z: float | ndarray,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    x: ndarray,
+    y: ndarray,
+    z: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     from observer to target, ECEF => ENU
 
@@ -302,13 +292,13 @@ def ecef2enu(
 
 
 def enu2uvw(
-    east: float,
-    north: float,
-    up: float,
-    lat0: float,
-    lon0: float,
+    east: ndarray,
+    north: ndarray,
+    up: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
     deg: bool = True,
-) -> tuple[float, float, float]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     Parameters
     ----------
@@ -342,8 +332,8 @@ def enu2uvw(
 
 
 def uvw2enu(
-    u: float, v: float, w: float, lat0: float, lon0: float, deg: bool = True
-) -> tuple[float, float, float]:
+    u: ndarray, v: ndarray, w: ndarray, lat0: ndarray, lon0: ndarray, deg: bool = True
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     Parameters
     ----------
@@ -384,7 +374,7 @@ def eci2geodetic(
     *,
     deg: bool = True,
     use_astropy: bool = True
-) -> tuple[float | ndarray, float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     convert Earth Centered Internal ECI to geodetic coordinates
 
@@ -427,9 +417,9 @@ def eci2geodetic(
 
 
 def geodetic2eci(
-    lat: float | ndarray,
-    lon: float | ndarray,
-    alt: float | ndarray,
+    lat: ndarray,
+    lon: ndarray,
+    alt: ndarray,
     t: datetime,
     ell: Ellipsoid = None,
     *,
@@ -478,15 +468,15 @@ def geodetic2eci(
 
 
 def enu2ecef(
-    e1: float,
-    n1: float,
-    u1: float,
-    lat0: float,
-    lon0: float,
-    h0: float,
+    e1: ndarray,
+    n1: ndarray,
+    u1: ndarray,
+    lat0: ndarray,
+    lon0: ndarray,
+    h0: ndarray,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[float, float, float]:
+) -> tuple[ndarray, ndarray, ndarray]:
     """
     ENU to ECEF
 
