@@ -37,17 +37,11 @@ def test_3d_geodetic2ecef():
     assert (x0, y0, z0) == approx(xyz0)
 
 
-@pytest.mark.parametrize(
-    "xyz", [(xyz0[0], xyz0[1], xyz0[2]), ([xyz0[0]], [xyz0[1]], [xyz0[2]])], ids=("scalar", "list")
-)
-def test_scalar_ecef2geodetic(xyz):
+def test_scalar_ecef2geodetic():
     """
     verify we can handle the wide variety of input data type users might use
     """
-    if isinstance(xyz[0], list):
-        pytest.importorskip("numpy")
-
-    lat, lon, alt = pm.ecef2geodetic(*xyz)
+    lat, lon, alt = pm.ecef2geodetic(xyz0[0], xyz0[1], xyz0[2])
 
     assert [lat, lon, alt] == approx(lla0, rel=1e-4)
 
@@ -61,6 +55,38 @@ def test_3d_ecef2geodetic():
     assert [lat, lon, alt] == approx(lla0, rel=1e-4)
 
 
+def test_array_ecef2geodetic():
+    """
+    tests ecef2geodetic can handle numpy array data in addition to singular floats
+    """
+    np = pytest.importorskip("numpy")
+    # test values with no points inside ellipsoid
+    lla0_array = (
+        np.array([lla0[0], lla0[0]]),
+        np.array([lla0[1], lla0[1]]),
+        np.array([lla0[2], lla0[2]]),
+    )
+    xyz = pm.geodetic2ecef(*lla0_array)
+    lats, lons, alts = pm.ecef2geodetic(*xyz)
+
+    assert lats == approx(lla0_array[0])
+    assert lons == approx(lla0_array[1])
+    assert alts == approx(lla0_array[2])
+
+    # test values with some (but not all) points inside ellipsoid
+    lla0_array_inside = (
+        np.array([lla0[0], lla0[0]]),
+        np.array([lla0[1], lla0[1]]),
+        np.array([lla0[2], -lla0[2]]),
+    )
+    xyz = pm.geodetic2ecef(*lla0_array_inside)
+    lats, lons, alts = pm.ecef2geodetic(*xyz)
+
+    assert lats == approx(lla0_array_inside[0])
+    assert lons == approx(lla0_array_inside[1])
+    assert alts == approx(lla0_array_inside[2])
+
+
 def test_xarray():
     xarray = pytest.importorskip("xarray")
     xr_lla = xarray.DataArray(list(lla0))
