@@ -1,11 +1,12 @@
 import pytest
 from pytest import approx
-import pymap3d as pm
+
+import pymap3d.lox as lox
 
 
 @pytest.mark.parametrize("lat,dist", [(0, 0), (90, 10001965.729)])
 def test_meridian_dist(lat, dist):
-    assert pm.meridian_dist(lat) == approx(dist)
+    assert lox.meridian_dist(lat) == approx(dist)
 
 
 @pytest.mark.parametrize(
@@ -23,7 +24,7 @@ def test_meridian_arc(lat1, lat2, arclen):
     meridianarc(deg2rad(40), deg2rad(80), wgs84Ellipsoid)
     """
 
-    assert pm.meridian_arc(lat1, lat2) == approx(arclen)
+    assert lox.meridian_arc(lat1, lat2) == approx(arclen)
 
 
 @pytest.mark.parametrize(
@@ -37,7 +38,7 @@ def test_meridian_arc(lat1, lat2, arclen):
     ],
 )
 def test_departure(lon1, lon2, lat, dist):
-    assert pm.departure(lon1, lon2, lat) == approx(dist)
+    assert lox.departure(lon1, lon2, lat) == approx(dist)
 
 
 @pytest.mark.parametrize(
@@ -57,7 +58,7 @@ def test_loxodrome_inverse(lat1, lon1, lat2, lon2, arclen, az):
     distance('rh', 40, -80, 65, -148, wgs84Ellipsoid)
     azimuth('rh', 40, -80, 65, -148, wgs84Ellipsoid)
     """
-    rhdist, rhaz = pm.loxodrome_inverse(lat1, lon1, lat2, lon2)
+    rhdist, rhaz = lox.loxodrome_inverse(lat1, lon1, lat2, lon2)
 
     assert rhdist == approx(arclen)
     assert rhaz == approx(az)
@@ -67,7 +68,7 @@ def test_loxodrome_inverse(lat1, lon1, lat2, lon2, arclen, az):
 
 def test_numpy_loxodrome_inverse():
     pytest.importorskip("numpy")
-    d, a = pm.loxodrome_inverse([40, 40], [-80, -80], 65, -148)
+    d, a = lox.loxodrome_inverse([40, 40], [-80, -80], 65, -148)
 
     assert d == approx(5248666.209)
     assert a == approx(302.00567)
@@ -85,7 +86,7 @@ def test_numpy_loxodrome_inverse():
     ],
 )
 def test_loxodrome_direct(lat0, lon0, rng, az, lat1, lon1):
-    lat2, lon2 = pm.loxodrome_direct(lat0, lon0, rng, az)
+    lat2, lon2 = lox.loxodrome_direct(lat0, lon0, rng, az)
     assert lat2 == approx(lat1, abs=1e-6)
     assert lon2 == approx(lon1)
     assert isinstance(lat2, float)
@@ -94,7 +95,7 @@ def test_loxodrome_direct(lat0, lon0, rng, az, lat1, lon1):
 
 def test_numpy_loxodrome_direct():
     pytest.importorskip("numpy")
-    lat, lon = pm.loxodrome_direct([40, 40], [-80, -80], [10000, 10000], [30, 30])
+    lat, lon = lox.loxodrome_direct([40, 40], [-80, -80], [10000, 10000], [30, 30])
     assert lat == approx(40.077995)
     assert lon == approx(-79.941414)
 
@@ -102,4 +103,4 @@ def test_numpy_loxodrome_direct():
 @pytest.mark.parametrize("lat,lon", [([0, 45, 90], [0, 45, 90])])
 def test_meanm(lat, lon):
     pytest.importorskip("numpy")
-    assert pm.meanm(lat, lon) == approx([47.26967, 18.460557])
+    assert lox.meanm(lat, lon) == approx([47.26967, 18.460557])
